@@ -13,10 +13,7 @@ class CenterColumnShieldHyperbola(RotateMixedShape):
         mid_radius: the inner radius of the outer hyperbolic profile of
             the center column shield.
         outer_radius: the outer radius of the center column shield.
-        stp_filename: Defaults to "CenterColumnShieldHyperbola.stp".
-        stl_filename: Defaults to "CenterColumnShieldHyperbola.stl".
         name: Defaults to "center_column".
-        material_tag: Defaults to "center_column_shield_mat".
     """
 
     def __init__(
@@ -25,10 +22,7 @@ class CenterColumnShieldHyperbola(RotateMixedShape):
         inner_radius: float,
         mid_radius: float,
         outer_radius: float,
-        stp_filename: Optional[str] = "CenterColumnShieldHyperbola.stp",
-        stl_filename: Optional[str] = "CenterColumnShieldHyperbola.stl",
         name: Optional[str] = "center_column",
-        material_tag: Optional[str] = "center_column_shield_mat",
         color: Optional[Tuple[float, float, float,
                               Optional[float]]] = (0., 0.333, 0.),
         **kwargs
@@ -36,9 +30,6 @@ class CenterColumnShieldHyperbola(RotateMixedShape):
 
         super().__init__(
             name=name,
-            material_tag=material_tag,
-            stp_filename=stp_filename,
-            stl_filename=stl_filename,
             color=color,
             **kwargs
         )
