@@ -13,9 +13,6 @@ class PoloidalFieldCoilCase(RotateStraightShape):
         coil_width: the horizontal (x axis) width of the coil (cm).
         center_point: the center of the coil (x,z) values (cm).
         casing_thickness: the thickness of the coil casing (cm).
-        stp_filename: defaults to "PoloidalFieldCoilCase.stp".
-        stl_filename: defaults to "PoloidalFieldCoilCase.stl".
-        material_tag: defaults to "pf_coil_case_mat".
     """
 
     def __init__(
@@ -24,17 +21,11 @@ class PoloidalFieldCoilCase(RotateStraightShape):
         coil_height: float,
         coil_width: float,
         center_point: Tuple[float, float],
-        stp_filename: Optional[str] = "PoloidalFieldCoilCase.stp",
-        stl_filename: Optional[str] = "PoloidalFieldCoilCase.stl",
-        material_tag: Optional[str] = "pf_coil_case_mat",
         color: Optional[Tuple[int, int, int]] = (1., 1., 0.498),
         **kwargs
     ) -> None:
 
         super().__init__(
-            material_tag=material_tag,
-            stp_filename=stp_filename,
-            stl_filename=stl_filename,
             color=color,
             **kwargs
         )
