@@ -64,19 +64,19 @@ class BallReactor(paramak.Reactor):
 
     def __init__(
             self,
-            inner_bore_radial_thickness: float,
-            inboard_tf_leg_radial_thickness: float,
-            center_column_shield_radial_thickness: float,
-            divertor_radial_thickness: float,
-            inner_plasma_gap_radial_thickness: float,
-            plasma_radial_thickness: float,
-            outer_plasma_gap_radial_thickness: float,
-            firstwall_radial_thickness: float,
-            blanket_radial_thickness: float,
-            blanket_rear_wall_radial_thickness: float,
-            elongation: float,
-            triangularity: float,
-            plasma_gap_vertical_thickness: float,
+            inner_bore_radial_thickness: float = 10.,
+            inboard_tf_leg_radial_thickness: float = 30.,
+            center_column_shield_radial_thickness: float = 60.,
+            divertor_radial_thickness: float = 150.,
+            inner_plasma_gap_radial_thickness: float = 30.,
+            plasma_radial_thickness: float = 300.,
+            outer_plasma_gap_radial_thickness: float = 30.,
+            plasma_gap_vertical_thickness: float = 50.,
+            firstwall_radial_thickness: float = 30.,
+            blanket_radial_thickness: float = 50.,
+            blanket_rear_wall_radial_thickness: float = 30.,
+            elongation: float = 2.,
+            triangularity: float = 0.55,
             divertor_to_tf_gap_vertical_thickness: Optional[float] = 0,
             number_of_tf_coils: Optional[int] = 12,
             rear_blanket_to_tf_gap: Optional[float] = None,
