@@ -45,20 +45,20 @@ class CenterColumnStudyReactor(paramak.Reactor):
 
     def __init__(
         self,
-        inner_bore_radial_thickness,
-        inboard_tf_leg_radial_thickness,
-        center_column_shield_radial_thickness_mid,
-        center_column_shield_radial_thickness_upper,
-        inboard_firstwall_radial_thickness,
-        divertor_radial_thickness,
-        inner_plasma_gap_radial_thickness,
-        plasma_radial_thickness,
-        outer_plasma_gap_radial_thickness,
-        center_column_arc_vertical_thickness,
-        elongation,
-        triangularity,
-        plasma_gap_vertical_thickness,
-        rotation_angle=360.0,
+        inner_bore_radial_thickness: float = 20,
+        inboard_tf_leg_radial_thickness: float = 50.,
+        center_column_shield_radial_thickness_mid: float = 50.,
+        center_column_shield_radial_thickness_upper: float = 100.,
+        inboard_firstwall_radial_thickness: float = 20.,
+        divertor_radial_thickness: float = 100.,
+        inner_plasma_gap_radial_thickness: float = 80.,
+        plasma_radial_thickness: float = 200.,
+        outer_plasma_gap_radial_thickness: float = 90,
+        center_column_arc_vertical_thickness: float = 520.,
+        elongation: float = 2.3,
+        triangularity: float = 0.45,
+        plasma_gap_vertical_thickness: float = 40,
+        rotation_angle: float = 360.0,
     ):
 
         super().__init__([])
