@@ -56,22 +56,22 @@ class SubmersionTokamak(paramak.Reactor):
 
     def __init__(
         self,
-        inner_bore_radial_thickness: float,
-        inboard_tf_leg_radial_thickness: float,
-        center_column_shield_radial_thickness: float,
-        inboard_blanket_radial_thickness: float,
-        firstwall_radial_thickness: float,
-        inner_plasma_gap_radial_thickness: float,
-        plasma_radial_thickness: float,
-        divertor_radial_thickness: float,
-        support_radial_thickness: float,
-        outer_plasma_gap_radial_thickness: float,
-        outboard_blanket_radial_thickness: float,
-        blanket_rear_wall_radial_thickness: float,
-        elongation: float,
-        triangularity: float,
+        inner_bore_radial_thickness: float = 30.,
+        inboard_tf_leg_radial_thickness: float = 30,
+        center_column_shield_radial_thickness: float = 30,
+        inboard_blanket_radial_thickness: float = 80,
+        firstwall_radial_thickness: float = 20,
+        inner_plasma_gap_radial_thickness: float = 50,
+        plasma_radial_thickness: float = 200,
+        divertor_radial_thickness: float = 80,
+        support_radial_thickness: float = 90,
+        outer_plasma_gap_radial_thickness: float = 50,
+        outboard_blanket_radial_thickness: float = 30,
+        blanket_rear_wall_radial_thickness: float = 30,
+        elongation: float = 2.,
+        triangularity: float = 0.5,
         number_of_tf_coils: int = 16,
-        rotation_angle: float = 360.0,
+        rotation_angle: float = 360.,
         outboard_tf_coil_radial_thickness: Optional[float] = None,
         rear_blanket_to_tf_gap: Optional[float] = None,
         outboard_tf_coil_poloidal_thickness: Optional[float] = None,
