@@ -15,10 +15,6 @@ class TestCenterColumnShieldCircular(unittest.TestCase):
         """Checks that the default parameters of a CenterColumnShieldCircular are correct."""
 
         assert self.test_shape.rotation_angle == 360
-        assert self.test_shape.stp_filename == "CenterColumnShieldCircular.stp"
-        assert self.test_shape.stl_filename == "CenterColumnShieldCircular.stl"
-        # assert self.test_shape.name == "center_column_shield"
-        assert self.test_shape.material_tag == "center_column_shield_mat"
 
     def test_points_calculation(self):
         """Checks that the points used to construct the CenterColumnShieldCircular components
