@@ -16,10 +16,6 @@ class TestCenterColumnShieldHyperbola(unittest.TestCase):
         correct."""
 
         assert self.test_shape.rotation_angle == 360
-        assert self.test_shape.stp_filename == "CenterColumnShieldHyperbola.stp"
-        assert self.test_shape.stl_filename == "CenterColumnShieldHyperbola.stl"
-        # assert self.test_shape.name == "center_column"
-        assert self.test_shape.material_tag == "center_column_shield_mat"
 
     def test_processed_points_calculation(self):
         """Checks that the processed_points used to construct the
